import React from 'react'
import PropTypes from 'prop-types'

import { css } from '@mxenabled/cssinjs'
import { Help } from '@kyper/icon/Help'
import { useTokens } from '@kyper/tokenprovider'

export const DescriptionText = ({ buttonPropsId, showDescriptionIcon, description }) => {
  const tokens = useTokens()
  const styles = getStyles(tokens)

  return (
    <p className={css(styles.textContainer)} id={`${buttonPropsId}-description`}>
      {showDescriptionIcon ? (
        <span className={css(styles.textIconContainer)}>
          <Help color={tokens.TextColor.InputLabel} size={12} />
        </span>
      ) : null}
      {description}
    </p>
  )
}

const getStyles = tokens => ({
  textContainer: {
    display: 'flex',
    marginTop: tokens.Spacing.Tiny,
    fontSize: tokens.FontSize.InputLabel,
    lineHeight: tokens.LineHeight.Small,
    color: tokens.TextColor.InputLabel,
    textAlign: 'left',
  },
  textIconContainer: {
    display: 'flex',
    marginRight: tokens.Spacing.Tiny,
    marginTop: tokens.Spacing.XTiny,
  },
})

DescriptionText.propTypes = {
  buttonPropsId: PropTypes.string,
  description: PropTypes.string,
  showDescriptionIcon: PropTypes.bool,
}
