import React from 'react'
import PropTypes from 'prop-types'

import { css } from '@mxenabled/cssinjs'
import { CloseFilled } from '@kyper/icon/CloseFilled'
import { useTokens } from '@kyper/tokenprovider'

export const ErrorText = ({ buttonPropsId, showErrorIcon, errorText }) => {
  const tokens = useTokens()
  const styles = getStyles(tokens)

  return (
    <p className={css(styles.errorContainer)} id={`${buttonPropsId}-error`}>
      {showErrorIcon ? (
        <span className={css(styles.textIconContainer)}>
          <CloseFilled color={tokens.TextColor.Error} size={12} />
        </span>
      ) : null}
      {errorText}
    </p>
  )
}

const getStyles = tokens => ({
  errorContainer: {
    display: 'flex',
    marginTop: tokens.Spacing.Tiny,
    fontSize: tokens.FontSize.InputLabel,
    lineHeight: tokens.LineHeight.Small,
    color: tokens.TextColor.Error,
    textAlign: 'left',
  },
  textIconContainer: {
    display: 'flex',
    marginRight: tokens.Spacing.Tiny,
    marginTop: tokens.Spacing.XTiny,
  },
})

ErrorText.propTypes = {
  buttonPropsId: PropTypes.string,
  errorText: PropTypes.string,
  showErrorIcon: PropTypes.bool,
}
