import PropTypes from 'prop-types'

// TODO: bold the letters that match in the list of items
export const getFilteredItems = (items = [], showAllItems = true, inputValue = '') => {
  if (showAllItems) return items
  const filterItems = items.filter(
    item =>
      item.value
        .toString()
        .toLowerCase()
        .includes(inputValue.toLowerCase()) ||
      (typeof item.label === 'string' &&
        item.label.toLowerCase().includes(inputValue.toLowerCase())) ||
      item.readableLabel?.toLowerCase().includes(inputValue.toLowerCase()),
  )

  return filterItems.length > 0
    ? filterItems
    : [
        {
          label: `No results for "${inputValue}"`,
          noCheckBox: true,
          doNotAllowSelection: true,
          value: 'No results found',
        },
      ]
}

export const itemShape = PropTypes.shape({
  /**
   * When you pass in a custom element as your label you need to also pass in a `readableLabel` to display in the search input when an item is selected.
   */
  label: PropTypes.oneOfType([PropTypes.string, PropTypes.node]).isRequired,
  /**
   * String to display in the search input when the item is selected.
   */
  readableLabel: PropTypes.string,
  /**
   * Item value.
   */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]).isRequired,
  labelCheck: (props, _, componentName) => {
    if (typeof props['label'] !== 'string' && !props['readableLabel']) {
      return new Error(
        `When using JSX as a label, you must provide a readableLabel for the ${componentName} component.`,
      )
    }

    return null
  },
})
